# プロジェクト統計レポート

最終更新: 2025-09-12 07:52:19


---

## 概要

- 対象ファイル数: 10546

- 総行数(概算): 1513459


## 言語別内訳

- json: 6576 files / 350923 lines
- markdown: 1266 files / 468021 lines
- python: 2476 files / 626129 lines
- yaml: 228 files / 68386 lines

## 主要ディレクトリ別ファイル数

- archive/backups/specs_backup_20250829_210807: 313
- archive/temp_files_legacy/cache/mypy/3.10: 275
- specs: 262
- temp/cache/mypy/3.10: 241
- src/noveler/application/use_cases/temp/cache/mypy/3.10: 197
- src/noveler/domain/services: 150
- archive/temp_files_legacy/cache/mypy/3.10/rich: 146
- temp/cache/mypy/3.10/rich: 146
- backups/domain_fixes/domain_dependency_fix/services: 142
- src/noveler/application/use_cases/temp/cache/mypy/3.10/rich: 138
- archive/temp_files_legacy/cache/mypy/3.10/noveler/domain/value_objects: 132
- temp/cache/mypy/3.10/noveler/domain/value_objects: 126
- src/noveler/domain/value_objects: 118
- backups/domain_fixes/domain_dependency_fix/value_objects: 117
- src/noveler/application/use_cases: 105

---

このレポートは scripts/generate_stats_report.py により自動生成されました。
